@@ -1,9 +1,9 @@
 from __future__ import annotations
-from typing import List
+
 import logging
 
 from dynamicprompts import constants
-from . import PromptGenerator
+from dynamicprompts.generators.promptgenerator import PromptGenerator
 
 logger = logging.getLogger(__name__)
 
@@ -13,7 +13,7 @@ class BatchedCombinatorialPromptGenerator(PromptGenerator):
         self._generator = generator
         self._batches = batches
 
-    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> List[str]:
+    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> list[str]:
         images = []
 
         for _ in range(self._batches):
