@@ -1,12 +1,12 @@
 from __future__ import annotations
 
 import logging
-from typing import List, Iterable
+from typing import Iterable
 
-from dynamicprompts.wildcardmanager import WildcardManager
 from dynamicprompts import constants
+from dynamicprompts.generators.promptgenerator import PromptGenerator
 from dynamicprompts.parser.combinatorial_generator import CombinatorialGenerator
-from . import PromptGenerator
+from dynamicprompts.wildcardmanager import WildcardManager
 
 logger = logging.getLogger(__name__)
 
