@@ -1,15 +1,15 @@
 from __future__ import annotations
 
-from typing import List
-
 import logging
 import random
 
 import requests
 
-from dynamicprompts.generators.promptgenerator import PromptGenerator, GeneratorException
-from dynamicprompts.generators import DummyGenerator
-
+from dynamicprompts.generators.dummygenerator import DummyGenerator
+from dynamicprompts.generators.promptgenerator import (
+    GeneratorException,
+    PromptGenerator,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -20,7 +20,7 @@ class FeelingLuckyGenerator(PromptGenerator):
         else:
             self._generator = generator
 
-    def generate(self, search_query, num_prompts: int) -> List[str]:
+    def generate(self, search_query, num_prompts: int) -> list[str]:
         search_query = self._generator.generate(search_query, 1)[0]
 
         if search_query.strip() == "":
@@ -29,7 +29,7 @@ class FeelingLuckyGenerator(PromptGenerator):
             query = search_query
 
         url = f"https://lexica.art/api/v1/search?q={query}"
-        
+
         try:
             logger.info(f"Requesting {url}")
             response = requests.get(url)
@@ -39,6 +39,4 @@ class FeelingLuckyGenerator(PromptGenerator):
             selected_prompts = random.choices(prompts, k=num_prompts)
             return [p["prompt"] for p in selected_prompts]
         except Exception as e:
-            raise GeneratorException("Error while generating prompt: " + str(e))
-
-
+            raise GeneratorException(f"Error while generating prompt: {e}") from e
