@@ -1,25 +1,22 @@
 from __future__ import annotations
 
 import logging
-from typing import List
-
-from .promptgenerator import PromptGenerator
-from dynamicprompts.generators import DummyGenerator
 import re
 
 from tqdm import trange
 
+from dynamicprompts.generators.dummygenerator import DummyGenerator
+from dynamicprompts.generators.promptgenerator import PromptGenerator
+
 logger = logging.getLogger(__name__)
 
 try:
-    from transformers import set_seed
-    from transformers import AutoTokenizer, AutoModelForCausalLM
-    from transformers import pipeline
-except ImportError:
+    from transformers import AutoModelForCausalLM, AutoTokenizer, pipeline, set_seed
+except ImportError as ie:
     raise ImportError(
         "You need to install the transformers library to use the MagicPrompt generator. "
         "You can do this by running `pip install -U dynamicprompts[magicprompt]`."
-    )
+    ) from ie
 
 DEFAULT_MODEL_NAME = "Gustavosta/MagicPrompt-Stable-Diffusion"
 MAX_SEED = 2 ** 32 - 1
@@ -65,7 +62,7 @@ class MagicPromptGenerator(PromptGenerator):
 
         self._max_prompt_length = max_prompt_length
         self._temperature = float(temperature)
-        
+
 
         if seed is not None:
             set_seed(int(seed))
@@ -82,8 +79,8 @@ class MagicPromptGenerator(PromptGenerator):
             self._generator = self._load_pipeline(model_name)
         else:
             self._generator = MagicPromptGenerator.generator
-    
-    def generate(self, *args, **kwargs) -> List[str]:
+
+    def generate(self, *args, **kwargs) -> list[str]:
         prompts = self._prompt_generator.generate(*args, **kwargs)
 
         new_prompts = []
